@@ -16,10 +16,7 @@ use crate::{
     Error,
 };
 use bls_dkg::key_gen::message::Message as DkgMessage;
-use sn_messaging::{
-    node::{DkgFailureProof, DkgFailureProofSet, DkgKey, ElderCandidates, Proposal, Variant},
-    DstLocation,
-};
+use sn_messaging::node::{DkgFailureProof, DkgFailureProofSet, DkgKey, ElderCandidates, Proposal};
 use std::{collections::BTreeSet, iter, net::SocketAddr, slice};
 use xor_name::XorName;
 
@@ -104,75 +101,21 @@ impl Core {
         }
     }
 
-    pub(crate) async fn handle_connectivity_complaint(
-        &self,
-        sender: XorName,
-        elder_name: XorName,
-    ) -> Result<Vec<Command>> {
-        self.connectivity_complaints
-            .add_complaint(sender, elder_name)
-            .await;
-
-        let weighing_adults: BTreeSet<XorName> = self
-            .section
-            .members()
-            .joined()
-            .map(|info| *info.peer.name())
-            .collect();
-        if self
-            .connectivity_complaints
-            .is_complained(elder_name, &weighing_adults)
-            .await
-        {
-            self.propose_offline(elder_name)
-        } else {
-            Ok(vec![])
-        }
-    }
-
-    fn complain_connectivity(&self, name: XorName) -> Result<Vec<Command>> {
-        if !self.is_elder() {
-            // When self is not an elder, then the peer has to be an elder, and we shall complaint
-            // the lost to other elders.
-            let variant = Variant::ConnectivityComplaint(name);
-            let recipients: Vec<_> = self
-                .section
-                .proven_authority_provider()
-                .value
-                .peers()
-                .filter(|peer| *peer.name() != name)
-                .collect();
-            trace!(
-                "Casting connectivity complaint against {:?} {:?}",
-                name,
-                recipients
-            );
-
-            return self.send_message_for_dst_accumulation(
-                self.node.name(),
-                DstLocation::DirectAndUnrouted,
-                variant,
-                &recipients,
-            );
-        }
-
-        self.propose_offline(name)
-    }
-
     pub fn handle_connection_lost(&self, addr: SocketAddr) -> Result<Vec<Command>> {
-        let name = if let Some(peer) = self.section.find_joined_member_by_addr(&addr) {
-            debug!("Lost connection to known peer {}", peer);
-            *peer.name()
+        if let Some(peer) = self.section.find_joined_member_by_addr(&addr) {
+            debug!(
+                "Possible connection loss detected with known peer {:?}",
+                peer
+            )
+        } else if let Some(end_user) = self.get_enduser_by_addr(&addr) {
+            debug!(
+                "Possible connection loss detected with known client {:?}",
+                end_user
+            )
         } else {
-            if let Some(end_user) = self.get_enduser_by_addr(&addr) {
-                debug!("Lost connection to client {:?}", end_user);
-            } else {
-                debug!("Lost connection to unknown peer {}", addr);
-            }
-            return Ok(vec![]);
-        };
-
-        self.complain_connectivity(name)
+            debug!("Possible connection loss detected with addr: {:?}", addr);
+        }
+        Ok(vec![])
     }
 
     pub fn handle_peer_lost(&self, addr: &SocketAddr) -> Result<Vec<Command>> {
@@ -184,7 +127,12 @@ impl Core {
             return Ok(vec![]);
         };
 
-        self.complain_connectivity(name)
+        if !self.is_elder() {
+            // Adults cannot complain about connectivity.
+            return Ok(vec![]);
+        }
+
+        self.propose_offline(name)
     }
 
     pub fn propose_offline(&self, name: XorName) -> Result<Vec<Command>> {
